==> cristalise-kernel-3.2-sources.jar: org/cristalise/kernel/graph/model/Graphable.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.graph.model;

/**
* @version $Revision: 1.6 $ $Date: 2003/05/12 13:10:20 $
* @author  $Author: abranson $
*/

import org.cristalise.kernel.utils.CastorHashMap;

abstract public class Graphable extends Vertex
{

    protected CastorHashMap        mProperties   = null;
	public GraphModel children;

    public void setProperties(CastorHashMap props)
    {
        mProperties = props;
    }

    public CastorHashMap getProperties()
    {
        return mProperties;
    }
	/** @associates Graphable that is directly containing it*/
	private Graphable parent;

	/**
	 * Returns the parent.
	 * @return Graphable
	 */
	public Graphable getParent()
	{
		return parent;
	}

	/**
	 * Sets the parent.
	 * @param parent The parent to set
	 */
	public void setParent(Graphable parent)
	{
		this.parent = parent;
	}
	@Override
	public GraphModel getChildGraphModel() {
		return children;
	}

	@Override
	public Object getCreationContext() {
		return this;
	}

}

==> cristalise-kernel-5.5.0-sources.jar: org/cristalise/kernel/graph/model/Graphable.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.graph.model;

/**
* @version $Revision: 1.6 $ $Date: 2003/05/12 13:10:20 $
* @author  $Author: abranson $
*/

import org.cristalise.kernel.utils.CastorHashMap;

abstract public class Graphable extends Vertex
{

    protected CastorHashMap        mProperties   = null;
	public GraphModel children;

    public void setProperties(CastorHashMap props)
    {
        mProperties = props;
    }

    public CastorHashMap getProperties()
    {
        return mProperties;
    }
	/** @associates Graphable that is directly containing it*/
	private Graphable parent;

	/**
	 * Returns the parent.
	 * @return Graphable
	 */
	public Graphable getParent()
	{
		return parent;
	}

	/**
	 * Sets the parent.
	 * @param parent The parent to set
	 */
	public void setParent(Graphable parent)
	{
		this.parent = parent;
	}
	@Override
	public GraphModel getChildrenGraphModel() {
		return children;
	}

	@Override
	public Object getCreationContext() {
		return this;
	}

}
